@@ -12,14 +12,11 @@
 
 import abc
 
-import six
-
 from ovsdbapp import api
 from ovsdbapp import constants as const
 
 
-@six.add_metaclass(abc.ABCMeta)
-class API(api.API):
+class API(api.API, metaclass=abc.ABCMeta):
     """An API based off of the ovn-nbctl CLI interface
 
     This API basically mirrors the ovn-nbctl operations with these changes:
@@ -223,7 +220,8 @@ class API(api.API):
         """
 
     @abc.abstractmethod
-    def qos_del(self, switch, direction=None, priority=None, match=None):
+    def qos_del(self, switch, direction=None, priority=None, match=None,
+                if_exists=True):
         """Remove Qos rules from 'switch'
 
         If only switch is supplied, all the QoS rules from the logical switch
@@ -240,6 +238,8 @@ class API(api.API):
         :type priority:   int
         :param match:     The match rule
         :type match:      string
+        :param if_exists: Do not fail if the Logical_Switch row does not exist
+        :type if_exists:  bool
         :returns:         :class:`Command` with no result
         """
 
@@ -252,6 +252,19 @@ class API(api.API):
         :returns:      :class:`Command` with RowView list result
         """
 
+    @abc.abstractmethod
+    def qos_del_ext_ids(self, lswitch_name, external_ids, if_exists=True):
+        """Delete all QoS rules related to a floating IP.
+
+        :param lswitch_name: The unique name of the logical switch
+        :type lswitch_name: string
+        :param external_ids: Pairs of key/value to find in the "external_ids"
+        :type external_ids: dict
+        :param if_exists: Do not fail if the Logical_Switch row does not exist
+        :type if_exists: bool
+        :returns: :class:`Command` with no result
+        """
+
     @abc.abstractmethod
     def lsp_add(self, switch, port, parent_name=None, tag=None,
                 may_exist=False, **columns):
@@ -686,11 +699,15 @@ class API(api.API):
     def lb_del(self, lb, vip=None, if_exists=False):
         """Remove a load balancer or just the VIP from a load balancer
 
+        If all vips of the load balancer are removed, the load balancer
+        instance will be removed as well. If vip parameter is 'None'
+        this will cause all vips (and load balancer) to be removed.
+
         :param lb:        The name or uuid of a load balancer
         :type lb:         string or uuid.UUID
-        :param vip:       The VIP on the load balancer to match
+        :param vip:       The VIP to match. If None, match all vips
         :type:            string
-        :param if_exists: If True, don't fail if the port doesn't exist
+        :param if_exists: If True, don't fail if the lb/vip doesn't exist
         :type if_exists:  boolean
         """
 
